package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TCarTaskPoint;

/**
 * 泄漏点Mapper接口
 * 
 * @author zehong
 * @date 2026-05-15
 */
public interface TCarTaskPointMapper 
{
    /**
     * 查询泄漏点
     * 
     * @param id 泄漏点ID
     * @return 泄漏点
     */
    public TCarTaskPoint selectTCarTaskPointById(Long id);

    /**
     * 查询泄漏点列表
     * 
     * @param tCarTaskPoint 泄漏点
     * @return 泄漏点集合
     */
    public List<TCarTaskPoint> selectTCarTaskPointList(TCarTaskPoint tCarTaskPoint);

    /**
     * 新增泄漏点
     * 
     * @param tCarTaskPoint 泄漏点
     * @return 结果
     */
    public int insertTCarTaskPoint(TCarTaskPoint tCarTaskPoint);

    /**
     * 修改泄漏点
     * 
     * @param tCarTaskPoint 泄漏点
     * @return 结果
     */
    public int updateTCarTaskPoint(TCarTaskPoint tCarTaskPoint);

    /**
     * 删除泄漏点
     * 
     * @param id 泄漏点ID
     * @return 结果
     */
    public int deleteTCarTaskPointById(Long id);

    /**
     * 批量删除泄漏点
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTCarTaskPointByIds(Long[] ids);
}
